Enum libreda_pnr::db::RLineIntersection
pub enum RLineIntersection<T>where
T: CoordinateType,{
None,
Point(Point<T>),
Collinear,
}Expand description
Return type for the line-line intersection functions. Stores all possible results of a line to line intersection.
Variants
None
No intersection at all.
Point(Point<T>)
Intersection in a single point.
Besides the intersection point also an other expression for the intersection point is given.
The three values (a, b, c) describe the intersection point in terms of a starting point (the starting point
of the edge which defines the line) and the direction of the edge multiplied by a fraction.
edge.start + edge.vector()*a/c == p and
other_edge.start + other_edge.vector()*b/c == p.
Collinear
Lines are collinear.