CellInstRef

Struct CellInstRef 

pub struct CellInstRef<'a, H>
where H: HierarchyBase + ?Sized,
{ /* private fields */ }
Default implementation for CellInstRef. This is just a wrapper around a netlist and a cell ID.

Implementations

Source

impl<'a, H> CellInstRef<'a, H>
where H: HierarchyBase,

pub fn base(&self) -> &H

Access the base structure.

pub fn id(&self) -> <H as HierarchyBase>::CellInstId

Get the ID of this cell instance.

pub fn name(&self) -> Option<<H as HierarchyBase>::NameType>

Get the name of the cell instance.

pub fn parent(&self) -> CellRef<'a, H>

Get the parent cell of this instance.

pub fn template(&self) -> CellRef<'a, H>

Get the template cell of this instance.

pub fn parent_id(&self) -> <H as HierarchyBase>::CellId

Get the ID of the parent cell of this instance.

pub fn template_id(&self) -> <H as HierarchyBase>::CellId

Get the ID of the template cell of this instance.

Source

impl<'a, N> CellInstRef<'a, N>
where N: NetlistBase,

pub fn each_pin_instance_id( &self, ) -> impl Iterator<Item = <N as NetlistBase>::PinInstId>

Iterate over the IDs of all pins of this cell.

pub fn each_pin_instance(&self) -> impl Iterator<Item = PinInstRef<'a, N>>

Iterate over all pins of this cell.

pub fn each_net(&self) -> impl Iterator<Item = NetRef<'a, N>>

Iterate over all nets are connected to this instance. A net might appear more than once.

Source

impl<'a, L> CellInstRef<'a, L>
where L: LayoutBase,

pub fn get_transform(&self) -> SimpleTransform<<L as LayoutBase>::Coord>

Get the geometric transform that describes the location of a cell instance relative to its parent.