pub struct CellRef<'a, H>where
H: HierarchyBase + ?Sized,{ /* private fields */ }Expand description
A reference to a cell. This is just a wrapper around a netlist and a cell ID.
Implementations
Sourceimpl<'a, H> CellRef<'a, H>where
H: HierarchyBase,
impl<'a, H> CellRef<'a, H>where
H: HierarchyBase,
Sourcepub fn id(&self) -> <H as HierarchyBase>::CellId
pub fn id(&self) -> <H as HierarchyBase>::CellId
Get the ID of this cell.
Sourcepub fn name(&self) -> <H as HierarchyBase>::NameType
pub fn name(&self) -> <H as HierarchyBase>::NameType
Get the name of the cell.
Sourcepub fn each_cell_instance_id(
&self,
) -> impl Iterator<Item = <H as HierarchyBase>::CellInstId>
pub fn each_cell_instance_id( &self, ) -> impl Iterator<Item = <H as HierarchyBase>::CellInstId>
Iterate over the IDs of all child instances.
Sourcepub fn each_cell_instance(&self) -> impl Iterator<Item = CellInstRef<'a, H>>
pub fn each_cell_instance(&self) -> impl Iterator<Item = CellInstRef<'a, H>>
Iterate over all child instances.
Sourcepub fn cell_instance_by_name(&self, name: &str) -> Option<CellInstRef<'a, H>>
pub fn cell_instance_by_name(&self, name: &str) -> Option<CellInstRef<'a, H>>
Find a child instance by its name.
Sourcepub fn each_reference_id(
&self,
) -> impl Iterator<Item = <H as HierarchyBase>::CellInstId>
pub fn each_reference_id( &self, ) -> impl Iterator<Item = <H as HierarchyBase>::CellInstId>
Iterate over the IDs of all instances of this cell.
Sourcepub fn each_reference(&self) -> impl Iterator<Item = CellInstRef<'a, H>>
pub fn each_reference(&self) -> impl Iterator<Item = CellInstRef<'a, H>>
Iterate over the of all instances of this cell.
Sourcepub fn num_references(&self) -> usize
pub fn num_references(&self) -> usize
Get the total number of usages of this cell.
Sourcepub fn each_cell_dependency(&self) -> impl Iterator<Item = CellRef<'a, H>>
pub fn each_cell_dependency(&self) -> impl Iterator<Item = CellRef<'a, H>>
Iterate over all dependencies of this cell.
Sourcepub fn num_cell_dependencies(&self) -> usize
pub fn num_cell_dependencies(&self) -> usize
Get the total number of direct dependencies of this cell.
Sourcepub fn each_dependent_cell(&self) -> impl Iterator<Item = CellRef<'a, H>>
pub fn each_dependent_cell(&self) -> impl Iterator<Item = CellRef<'a, H>>
Iterate over all cells that directly depend on this cell.
Sourcepub fn num_dependent_cells(&self) -> usize
pub fn num_dependent_cells(&self) -> usize
Get the total number of cells which depend on this cell (i.e. use it).
Sourcepub fn num_child_instances(&self) -> usize
pub fn num_child_instances(&self) -> usize
Get the number of cell instances inside the cell.
Sourceimpl<'a, N> CellRef<'a, N>where
N: NetlistBase,
impl<'a, N> CellRef<'a, N>where
N: NetlistBase,
Sourcepub fn each_pin_id(&self) -> impl Iterator<Item = <N as NetlistBase>::PinId>
pub fn each_pin_id(&self) -> impl Iterator<Item = <N as NetlistBase>::PinId>
Iterate over the IDs of all pins of this cell.
Sourcepub fn each_pin(&self) -> impl Iterator<Item = PinRef<'a, N>>
pub fn each_pin(&self) -> impl Iterator<Item = PinRef<'a, N>>
Iterate over all pins of this cell.
Sourcepub fn each_input_pin(&self) -> impl Iterator<Item = PinRef<'a, N>>
pub fn each_input_pin(&self) -> impl Iterator<Item = PinRef<'a, N>>
Iterate over all input pins of this cell.
Sourcepub fn each_output_pin(&self) -> impl Iterator<Item = PinRef<'a, N>>
pub fn each_output_pin(&self) -> impl Iterator<Item = PinRef<'a, N>>
Iterate over all output pins of this cell.
Sourcepub fn pin_by_name(&self, name: &str) -> Option<PinRef<'a, N>>
pub fn pin_by_name(&self, name: &str) -> Option<PinRef<'a, N>>
Find a pin by it’s name.
Sourcepub fn each_net(&self) -> impl Iterator<Item = NetRef<'a, N>>
pub fn each_net(&self) -> impl Iterator<Item = NetRef<'a, N>>
Iterate over all nets that live directly in this cell.
Sourcepub fn num_internal_nets(&self) -> usize
pub fn num_internal_nets(&self) -> usize
Get the number of nets inside this cell.
Sourcepub fn net_by_name(&self, name: &str) -> Option<NetRef<'a, N>>
pub fn net_by_name(&self, name: &str) -> Option<NetRef<'a, N>>
Find a net by its name.
Sourceimpl<'a, L> CellRef<'a, L>where
L: LayoutBase,
impl<'a, L> CellRef<'a, L>where
L: LayoutBase,
Sourcepub fn each_shape_per_layer(
&self,
layer_id: &<L as LayoutBase>::LayerId,
) -> impl Iterator<Item = ShapeRef<'_, L>>
pub fn each_shape_per_layer( &self, layer_id: &<L as LayoutBase>::LayerId, ) -> impl Iterator<Item = ShapeRef<'_, L>>
Iterate over all shapes on a layer.
Sourcepub fn each_shape(&self) -> impl Iterator<Item = ShapeRef<'_, L>>
pub fn each_shape(&self) -> impl Iterator<Item = ShapeRef<'_, L>>
Iterate over all shapes defined in this cell.
Sourcepub fn bounding_box_per_layer(
&self,
layer_id: &<L as LayoutBase>::LayerId,
) -> Option<Rect<<L as LayoutBase>::Coord>>
pub fn bounding_box_per_layer( &self, layer_id: &<L as LayoutBase>::LayerId, ) -> Option<Rect<<L as LayoutBase>::Coord>>
Get the bounding box of the shapes on a specific layer.
Sourcepub fn bounding_box(&self) -> Option<Rect<<L as LayoutBase>::Coord>>
pub fn bounding_box(&self) -> Option<Rect<<L as LayoutBase>::Coord>>
Get the bounding box of the shapes on all layers.