Struct libreda_pnr::db::Matrix3dTransform
pub struct Matrix3dTransform<T>where
T: CoordinateType,{
pub m11: T,
pub m12: T,
pub m21: T,
pub m22: T,
pub m31: T,
pub m32: T,
}Expand description
Affine transformation represented as a 3x3 matrix like:
m11 m12 0
m21 m22 0
m31 m32 1
Fields
m11: Tm11
m12: Tm12
m21: Tm21
m22: Tm22
m31: Tm31. Used to express the x component of the translation.
m32: Tm32. Used to express the y component of the translation.
Implementations
impl<T> Matrix3dTransform<T>where
T: CoordinateType,
impl<T> Matrix3dTransform<T>where T: CoordinateType,
pub fn new(
m11: T,
m12: T,
m21: T,
m22: T,
m31: T,
m32: T
) -> Matrix3dTransform<T>
pub fn new( m11: T, m12: T, m21: T, m22: T, m31: T, m32: T ) -> Matrix3dTransform<T>
Create a new transform based on the matrix elements.
pub fn identity() -> Matrix3dTransform<T>
pub fn identity() -> Matrix3dTransform<T>
Get the identity transform.
pub fn translate<V>(v: V) -> Matrix3dTransform<T>where
V: Into<Vector<T>>,
pub fn translate<V>(v: V) -> Matrix3dTransform<T>where V: Into<Vector<T>>,
Create a translation by a vector.
pub fn rotate90(angle: Angle) -> Matrix3dTransform<T>
pub fn rotate90(angle: Angle) -> Matrix3dTransform<T>
Create a rotation by an integer multiple of 90 degrees.
pub fn scale(factor: T) -> Matrix3dTransform<T>
pub fn scale(factor: T) -> Matrix3dTransform<T>
Create a scaling by a factor.
pub fn mirror_x() -> Matrix3dTransform<T>
pub fn mirror_x() -> Matrix3dTransform<T>
Mirror at the x-axis.
pub fn mirror_y() -> Matrix3dTransform<T>
pub fn mirror_y() -> Matrix3dTransform<T>
Mirror at the y-axis.
pub fn transform_point(&self, p: Point<T>) -> Point<T>
pub fn transform_point(&self, p: Point<T>) -> Point<T>
Apply the transformation to a single point.
pub fn to_matrix3d(&self) -> Matrix3d<T>
pub fn to_matrix3d(&self) -> Matrix3d<T>
Return the 3x3 matrix describing this transformation.
pub fn to_matrix2d(&self) -> Matrix2d<T>
pub fn to_matrix2d(&self) -> Matrix2d<T>
Return the 2x2 matrix that describes this transformation without any translation.
pub fn determinant(&self) -> T
pub fn determinant(&self) -> T
Compute the determinant of the 3x3 matrix that describes this transformation.
pub fn try_invert(&self) -> Option<Matrix3dTransform<T>>
pub fn try_invert(&self) -> Option<Matrix3dTransform<T>>
Get the inverse transformation if it exists.
pub fn then(&self, t: &Matrix3dTransform<T>) -> Matrix3dTransform<T>
pub fn then(&self, t: &Matrix3dTransform<T>) -> Matrix3dTransform<T>
Return a new transformation that is equal to applying
first self then t.
pub fn then_scale(&self, factor: T) -> Matrix3dTransform<T>
pub fn then_scale(&self, factor: T) -> Matrix3dTransform<T>
Create a new transformation with an additional scaling.
pub fn then_translate<V>(&self, v: V) -> Matrix3dTransform<T>where
V: Into<Vector<T>>,
pub fn then_translate<V>(&self, v: V) -> Matrix3dTransform<T>where V: Into<Vector<T>>,
Create a new transformation with an additional translation.
pub fn then_rotate90(&self, angle: Angle) -> Matrix3dTransform<T>
pub fn then_rotate90(&self, angle: Angle) -> Matrix3dTransform<T>
Create a new transformation with an additional rotation by a multiple of 90 degrees.
pub fn then_mirror_x(&self) -> Matrix3dTransform<T>
pub fn then_mirror_x(&self) -> Matrix3dTransform<T>
Create a new transformation with an additional mirroring at the x-axis.
pub fn then_mirror_y(&self) -> Matrix3dTransform<T>
pub fn then_mirror_y(&self) -> Matrix3dTransform<T>
Create a new transformation with an additional mirroring at the y-axis.
pub fn get_translation(&self) -> Vector<T>
pub fn get_translation(&self) -> Vector<T>
Get the translation part of this affine transformation.
impl<T> Matrix3dTransform<T>where
T: CoordinateType + Float,
impl<T> Matrix3dTransform<T>where T: CoordinateType + Float,
pub fn rotation(phi: T) -> Matrix3dTransform<T>
pub fn rotation(phi: T) -> Matrix3dTransform<T>
Create a rotation by an arbitrary angle (in radians).
pub fn then_rotate(&self, phi: T) -> Matrix3dTransform<T>
pub fn then_rotate(&self, phi: T) -> Matrix3dTransform<T>
Create a new transformation with an additional rotation.