pub trait NetlistReader {
    type Error;

    // Required method
    fn read_into_netlist<R, N>(
        &self,
        reader: &mut R,
        netlist: &mut N
    ) -> Result<(), Self::Error>
       where R: Read,
             N: NetlistEdit;

    // Provided method
    fn read_netlist<R, N>(&self, reader: &mut R) -> Result<N, Self::Error>
       where R: Read,
             N: NetlistEdit + Default { ... }
}
Read a netlist from a byte stream.

Required Associated Types

source

type Error

Type of error that could happen while reading a netlist.

Required Methods

source

fn read_into_netlist<R, N>( &self, reader: &mut R, netlist: &mut N ) -> Result<(), Self::Error>where R: Read, N: NetlistEdit,

Read a netlist from a byte stream and populate the netlist data structure.

Provided Methods

source

fn read_netlist<R, N>(&self, reader: &mut R) -> Result<N, Self::Error>where R: Read, N: NetlistEdit + Default,

Read a netlist from a byte stream.

Implementors