Struct libreda_pnr::db::traits::layout_ids_portrait::imports::reference_access::PinInstRef
source · pub struct PinInstRef<'a, N>where
N: NetlistBase + ?Sized,{
pub(super) base: &'a N,
pub(super) id: <N as NetlistIds>::PinInstId,
}Expand description
A reference to a pin instance. This is just a wrapper around a netlist and a pin instance ID.
Fields
base: &'a Nid: <N as NetlistIds>::PinInstIdImplementations
sourceimpl<'a, N> PinInstRef<'a, N>where
N: NetlistBase,
impl<'a, N> PinInstRef<'a, N>where N: NetlistBase,
sourcepub fn id(&self) -> <N as NetlistIds>::PinInstId
pub fn id(&self) -> <N as NetlistIds>::PinInstId
Get the pin instance ID.
sourcepub fn terminal_id(&self) -> TerminalId<N>
pub fn terminal_id(&self) -> TerminalId<N>
Get the terminal ID of this pin instance.
sourcepub fn cell_instance(&self) -> CellInstRef<'a, N>
pub fn cell_instance(&self) -> CellInstRef<'a, N>
Get the parent cell instance.
sourcepub fn into_terminal(self) -> TerminalRef<'a, N>
pub fn into_terminal(self) -> TerminalRef<'a, N>
Convert the pin instance reference into a terminal reference.