pub struct CellRef<'a, H>where
    H: HierarchyBase + ?Sized,{
    pub(super) base: &'a H,
    pub(super) id: <H as HierarchyIds>::CellId,
}
A reference to a cell. This is just a wrapper around a netlist and a cell ID.

Fields

base: &'a Hid: <H as HierarchyIds>::CellId

Implementations

source

impl<'a, H> CellRef<'a, H>where H: HierarchyBase,

source

pub fn base(&self) -> &H

Access the base structure.

source

pub fn id(&self) -> <H as HierarchyIds>::CellId

Get the ID of this cell.

source

pub fn name(&self) -> <H as HierarchyBase>::NameType

Get the name of the cell.

source

pub fn each_cell_instance_id( &self ) -> impl Iterator<Item = <H as HierarchyIds>::CellInstId>

Iterate over the IDs of all child instances.

source

pub fn each_cell_instance(&self) -> impl Iterator<Item = CellInstRef<'a, H>>

Iterate over all child instances.

source

pub fn cell_instance_by_name(&self, name: &str) -> Option<CellInstRef<'a, H>>

Find a child instance by its name.

source

pub fn each_reference_id( &self ) -> impl Iterator<Item = <H as HierarchyIds>::CellInstId>

Iterate over the IDs of all instances of this cell.

source

pub fn each_reference(&self) -> impl Iterator<Item = CellInstRef<'a, H>>

Iterate over the of all instances of this cell.

source

pub fn num_references(&self) -> usize

Get the total number of usages of this cell.

source

pub fn each_cell_dependency(&self) -> impl Iterator<Item = CellRef<'a, H>>

Iterate over all dependencies of this cell.

source

pub fn num_cell_dependencies(&self) -> usize

Get the total number of direct dependencies of this cell.

source

pub fn each_dependent_cell(&self) -> impl Iterator<Item = CellRef<'a, H>>

Iterate over all cells that directly depend on this cell.

source

pub fn num_dependent_cells(&self) -> usize

Get the total number of cells which depend on this cell (i.e. use it).

source

pub fn num_child_instances(&self) -> usize

Get the number of cell instances inside the cell.

source

impl<'a, L> CellRef<'a, L>where L: LayoutBase,

source

pub fn each_shape_per_layer( &self, layer_id: &<L as LayoutIds>::LayerId ) -> impl Iterator<Item = ShapeRef<'_, L>>

Iterate over all shapes on a layer.

source

pub fn each_shape(&self) -> impl Iterator<Item = ShapeRef<'_, L>>

Iterate over all shapes defined in this cell.

source

pub fn bounding_box_per_layer( &self, layer_id: &<L as LayoutIds>::LayerId ) -> Option<Rect<<L as LayoutIds>::Coord>>

Get the bounding box of the shapes on a specific layer.

source

pub fn bounding_box(&self) -> Option<Rect<<L as LayoutIds>::Coord>>

Get the bounding box of the shapes on all layers.

source

impl<'a, N> CellRef<'a, N>where N: NetlistBase,

source

pub fn each_pin_id(&self) -> impl Iterator<Item = <N as NetlistIds>::PinId>

Iterate over the IDs of all pins of this cell.

source

pub fn each_pin(&self) -> impl Iterator<Item = PinRef<'a, N>>

Iterate over all pins of this cell.

source

pub fn each_input_pin(&self) -> impl Iterator<Item = PinRef<'a, N>>

Iterate over all input pins of this cell.

source

pub fn each_output_pin(&self) -> impl Iterator<Item = PinRef<'a, N>>

Iterate over all output pins of this cell.

source

pub fn pin_by_name(&self, name: &str) -> Option<PinRef<'a, N>>

Find a pin by it’s name.

source

pub fn each_net(&self) -> impl Iterator<Item = NetRef<'a, N>>

Iterate over all nets that live directly in this cell.

source

pub fn num_internal_nets(&self) -> usize

Get the number of nets inside this cell.

source

pub fn net_by_name(&self, name: &str) -> Option<NetRef<'a, N>>

Find a net by its name.