Trait libreda_pnr::db::traits::HierarchyEditUtil
source · pub trait HierarchyEditUtil: HierarchyEdit {
// Provided methods
fn clear_cell_instances(&mut self, cell: &Self::CellId) { ... }
fn prune_cell_instance(&mut self, inst: &Self::CellInstId) { ... }
fn prune_cell(&mut self, cell: &Self::CellId) { ... }
}Expand description
Modifying utility functions for the cell hierarchy..
Import the this trait to use the utility functions all types that implement the HierarchyEdit trait.
Provided Methods
sourcefn clear_cell_instances(&mut self, cell: &Self::CellId)
fn clear_cell_instances(&mut self, cell: &Self::CellId)
Remove all child instances inside the cell.
sourcefn prune_cell_instance(&mut self, inst: &Self::CellInstId)
fn prune_cell_instance(&mut self, inst: &Self::CellInstId)
Remove the cell instance and all cells which are then not used anymore.
sourcefn prune_cell(&mut self, cell: &Self::CellId)
fn prune_cell(&mut self, cell: &Self::CellId)
Remove the cell and all other cells which are then not used anymore.