Struct libreda_pnr::design::SimpleDesignRef
source · pub struct SimpleDesignRef<'a, C: L2NBase> {
pub fused_layout_netlist: &'a C,
pub top_cell: C::CellId,
pub cell_outlines: &'a HashMap<C::CellId, Rect<C::Coord>>,
pub placement_region: &'a Vec<SimpleRPolygon<C::Coord>>,
pub placement_status: &'a HashMap<C::CellInstId, PlacementStatus>,
pub net_weights: &'a HashMap<C::NetId, f64>,
pub placement_location: &'a HashMap<C::CellInstId, SimpleTransform<C::Coord>>,
}Expand description
Collection of data representing the chip during the place & route flow.
This struct borrows the data. In contrast, SimpleDesign owns
the data.
Fields
fused_layout_netlist: &'a CBase layout and netlist data-structure.
top_cell: C::CellIdCell which contains the instances to be placed.
cell_outlines: &'a HashMap<C::CellId, Rect<C::Coord>>Outline shapes of the cells to be placed.
placement_region: &'a Vec<SimpleRPolygon<C::Coord>>Regions where cells are allowed to be placed.
placement_status: &'a HashMap<C::CellInstId, PlacementStatus>Placement status of the cell instances. Default is Movable.
net_weights: &'a HashMap<C::NetId, f64>Net weights. Default for nets which are not in the hash map is 1.0.
placement_location: &'a HashMap<C::CellInstId, SimpleTransform<C::Coord>>Overwrite the location information from the fused_layout_netlist.