pub fn net_bounding_box<C: L2NBase>(
    net: &NetRef<'_, C>
) -> Option<Rect<C::Coord>>
Get the bounding box around all the pins connected to net. None is returned when net is not connected to any pins or pin instances.