pub enum PlacementError {
ReachedMaxIterations,
Divergence,
Other(String),
}Expand description
Error type used for global placement.
Variants
ReachedMaxIterations
Stopped placement algorithm because the maximal number of iterations was reached.
Divergence
The solution diverges. This is likely a bug in the placement algorithm.
Other(String)
Other type of error. Defined by an error message string.