pub enum PlacementStatus {
Fixed,
Movable,
Ignore,
}Expand description
Describe the placement status of a cell instance.
Variants
Fixed
The instance location is fixed and must remain.
Movable
The instance can be put into another location by the placement engine.
Ignore
The instance should be ignored by the placement engine.