pub trait NetlistWriter {
    type Error;

    // Required method
    fn write_netlist<W, N>(
        &self,
        writer: &mut W,
        netlist: &N
    ) -> Result<(), Self::Error>
       where W: Write,
             N: NetlistBase;
}
Write a netlist to a byte stream.

Required Associated Types

source

type Error

Type of error that could happen while writing a netlist.

Required Methods

source

fn write_netlist<W, N>( &self, writer: &mut W, netlist: &N ) -> Result<(), Self::Error>where W: Write, N: NetlistBase,

Write the netlist data structure to a byte stream.

Implementors