pub struct PinRef<'a, N>where
N: NetlistBase + ?Sized,{ /* private fields */ }Expand description
A reference to a pin. This is just a wrapper around a netlist and a pin ID.
Implementations
Sourceimpl<'a, N> PinRef<'a, N>where
N: NetlistBase,
impl<'a, N> PinRef<'a, N>where
N: NetlistBase,
Sourcepub fn id(&self) -> <N as NetlistBase>::PinId
pub fn id(&self) -> <N as NetlistBase>::PinId
Get the pin ID.
Sourcepub fn terminal_id(&self) -> TerminalId<N>
pub fn terminal_id(&self) -> TerminalId<N>
Get the terminal ID of this pin.
Sourcepub fn name(&self) -> <N as HierarchyBase>::NameType
pub fn name(&self) -> <N as HierarchyBase>::NameType
Get the name of the pin.
Sourcepub fn net(&self) -> Option<NetRef<'a, N>>
pub fn net(&self) -> Option<NetRef<'a, N>>
Get the net which is attached to the pin from inside the cell.
Sourcepub fn instance(
&self,
cell_inst: &<N as HierarchyBase>::CellInstId,
) -> PinInstRef<'a, N>
pub fn instance( &self, cell_inst: &<N as HierarchyBase>::CellInstId, ) -> PinInstRef<'a, N>
Find the instance of this pin in the given cell instance.
Sourcepub fn into_terminal(self) -> TerminalRef<'a, N>
pub fn into_terminal(self) -> TerminalRef<'a, N>
Convert the pin reference into a terminal reference.