Function libreda_pnr::place::placement_solution::db::traits::copy_pins
source · pub fn copy_pins<NS, ND>(
dest_netlist: &mut ND,
dest_cell: &<ND as HierarchyIds>::CellId,
source_netlist: &NS,
source_cell: &<NS as HierarchyIds>::CellId
)where
NS: NetlistBase,
ND: NetlistEdit,Expand description
Copy the pin definitoins from a cell to another cell in another netlist.
Panics
Panics if a pin name is already occupied at the destination cell.