Function libreda_pnr::place::stdcell_placer::copy_layer_preserve_id
source · pub fn copy_layer_preserve_id<LS, LT>(
target_layout: &mut LT,
source_layout: &LS,
source_layer: &<LS as LayoutIds>::LayerId
) -> <LT as LayoutIds>::LayerIdwhere
LS: LayoutBase,
LT: LayoutEdit<LayerId = <LS as LayoutIds>::LayerId>,Expand description
Copy a layer (without its content) from a source layout into a destination layout
while preserving the layer ID.
LayerId types of the both layouts must be the same.
Panics
Panics if the layer number or layer name already exists.