pub enum TerminalRef<'a, N>where
    N: NetlistBase + ?Sized,{
    Pin(PinRef<'a, N>),
    PinInst(PinInstRef<'a, N>),
}
Either a pin or a pin instance.

Variants



Pin(PinRef<'a, N>)

A template pin.



PinInst(PinInstRef<'a, N>)

An instance of a pin.

Implementations

source

impl<'a, N> TerminalRef<'a, N>where N: NetlistBase,

source

pub fn id(&self) -> TerminalId<N>

Get the ID of the terminal.

source

pub fn base(&self) -> &N

Get a reference to the netlist structure.

source

pub fn net(&self) -> Option<NetRef<'a, N>>

Get the attached net.

source

pub fn pin_name(&self) -> <N as HierarchyBase>::NameType

Get the name of the pin.

source

pub fn parent(&self) -> CellRef<'_, N>

Get the parent cell of this terminal. For a pin, this equals the cell where the pin is defined. For a pin instance, this equals the parent of the cell instance which contains the pin instance.

source

pub fn qname(&self, separator: &str) -> String

Create a qualified name. For pins: ‘cell_name:pin_name’ For pin instances: ‘cell_name:cell_instance:pin_name’ Where : is defined by separator.