Struct libreda_pnr::place::stdcell_placer::layout_ids_portrait::imports::traits::CellRef
source · pub struct CellRef<'a, H>where
H: HierarchyBase + ?Sized,{
pub(super) base: &'a H,
pub(super) id: <H as HierarchyIds>::CellId,
}Expand description
A reference to a cell. This is just a wrapper around a netlist and a cell ID.
Fields
base: &'a Hid: <H as HierarchyIds>::CellIdImplementations
sourceimpl<'a, H> CellRef<'a, H>where
H: HierarchyBase,
impl<'a, H> CellRef<'a, H>where H: HierarchyBase,
sourcepub fn id(&self) -> <H as HierarchyIds>::CellId
pub fn id(&self) -> <H as HierarchyIds>::CellId
Get the ID of this cell.
sourcepub fn name(&self) -> <H as HierarchyBase>::NameType
pub fn name(&self) -> <H as HierarchyBase>::NameType
Get the name of the cell.
sourcepub fn each_cell_instance_id(
&self
) -> impl Iterator<Item = <H as HierarchyIds>::CellInstId>
pub fn each_cell_instance_id( &self ) -> impl Iterator<Item = <H as HierarchyIds>::CellInstId>
Iterate over the IDs of all child instances.
sourcepub fn each_cell_instance(&self) -> impl Iterator<Item = CellInstRef<'a, H>>
pub fn each_cell_instance(&self) -> impl Iterator<Item = CellInstRef<'a, H>>
Iterate over all child instances.
sourcepub fn cell_instance_by_name(&self, name: &str) -> Option<CellInstRef<'a, H>>
pub fn cell_instance_by_name(&self, name: &str) -> Option<CellInstRef<'a, H>>
Find a child instance by its name.
sourcepub fn each_reference_id(
&self
) -> impl Iterator<Item = <H as HierarchyIds>::CellInstId>
pub fn each_reference_id( &self ) -> impl Iterator<Item = <H as HierarchyIds>::CellInstId>
Iterate over the IDs of all instances of this cell.
sourcepub fn each_reference(&self) -> impl Iterator<Item = CellInstRef<'a, H>>
pub fn each_reference(&self) -> impl Iterator<Item = CellInstRef<'a, H>>
Iterate over the of all instances of this cell.
sourcepub fn num_references(&self) -> usize
pub fn num_references(&self) -> usize
Get the total number of usages of this cell.
sourcepub fn each_cell_dependency(&self) -> impl Iterator<Item = CellRef<'a, H>>
pub fn each_cell_dependency(&self) -> impl Iterator<Item = CellRef<'a, H>>
Iterate over all dependencies of this cell.
sourcepub fn num_cell_dependencies(&self) -> usize
pub fn num_cell_dependencies(&self) -> usize
Get the total number of direct dependencies of this cell.
sourcepub fn each_dependent_cell(&self) -> impl Iterator<Item = CellRef<'a, H>>
pub fn each_dependent_cell(&self) -> impl Iterator<Item = CellRef<'a, H>>
Iterate over all cells that directly depend on this cell.
sourcepub fn num_dependent_cells(&self) -> usize
pub fn num_dependent_cells(&self) -> usize
Get the total number of cells which depend on this cell (i.e. use it).
sourcepub fn num_child_instances(&self) -> usize
pub fn num_child_instances(&self) -> usize
Get the number of cell instances inside the cell.
sourceimpl<'a, L> CellRef<'a, L>where
L: LayoutBase,
impl<'a, L> CellRef<'a, L>where L: LayoutBase,
sourcepub fn each_shape_per_layer(
&self,
layer_id: &<L as LayoutIds>::LayerId
) -> impl Iterator<Item = ShapeRef<'_, L>>
pub fn each_shape_per_layer( &self, layer_id: &<L as LayoutIds>::LayerId ) -> impl Iterator<Item = ShapeRef<'_, L>>
Iterate over all shapes on a layer.
sourcepub fn each_shape(&self) -> impl Iterator<Item = ShapeRef<'_, L>>
pub fn each_shape(&self) -> impl Iterator<Item = ShapeRef<'_, L>>
Iterate over all shapes defined in this cell.
sourceimpl<'a, N> CellRef<'a, N>where
N: NetlistBase,
impl<'a, N> CellRef<'a, N>where N: NetlistBase,
sourcepub fn each_pin_id(&self) -> impl Iterator<Item = <N as NetlistIds>::PinId>
pub fn each_pin_id(&self) -> impl Iterator<Item = <N as NetlistIds>::PinId>
Iterate over the IDs of all pins of this cell.
sourcepub fn each_pin(&self) -> impl Iterator<Item = PinRef<'a, N>>
pub fn each_pin(&self) -> impl Iterator<Item = PinRef<'a, N>>
Iterate over all pins of this cell.
sourcepub fn each_input_pin(&self) -> impl Iterator<Item = PinRef<'a, N>>
pub fn each_input_pin(&self) -> impl Iterator<Item = PinRef<'a, N>>
Iterate over all input pins of this cell.
sourcepub fn each_output_pin(&self) -> impl Iterator<Item = PinRef<'a, N>>
pub fn each_output_pin(&self) -> impl Iterator<Item = PinRef<'a, N>>
Iterate over all output pins of this cell.
sourcepub fn pin_by_name(&self, name: &str) -> Option<PinRef<'a, N>>
pub fn pin_by_name(&self, name: &str) -> Option<PinRef<'a, N>>
Find a pin by it’s name.
sourcepub fn each_net(&self) -> impl Iterator<Item = NetRef<'a, N>>
pub fn each_net(&self) -> impl Iterator<Item = NetRef<'a, N>>
Iterate over all nets that live directly in this cell.
sourcepub fn num_internal_nets(&self) -> usize
pub fn num_internal_nets(&self) -> usize
Get the number of nets inside this cell.
sourcepub fn net_by_name(&self, name: &str) -> Option<NetRef<'a, N>>
pub fn net_by_name(&self, name: &str) -> Option<NetRef<'a, N>>
Find a net by its name.