Trait definition for buffer insertion algorithms.
Traits
- Simple
Buffer Insertion - Create a simple buffer tree between a specified source pin and a set of sink pins. The insertion strategy is up to the trait implementation.
Trait definition for buffer insertion algorithms.