pub struct AirWireRouter {
    air_wire_layer: u8,
    wire_thickness: SInt,
    full_mesh: bool,
}
Router that creates air wires between routing terminals in a star-topology. This does not produce a legal routing and has the only purpose to visualize the connectivity of components.

Fields

air_wire_layer: u8

Layer for the air wires.

wire_thickness: SInt

Wire thickness.

full_mesh: bool

Draw a full mesh instead of a star network.

Implementations

source

impl AirWireRouter

source

pub fn new(air_wire_layer: u8, wire_thickness: SInt, full_mesh: bool) -> Self

Create a default router.