pub trait PinAccessOracle<LN>where
    LN: LayoutBase + NetlistBase,{
    // Required method
    fn get_best_pin_access_location_with_via(
        &self,
        chip: &LN,
        pin_inst: &LN::PinInstId
    ) -> (Point<LN::Coord>, LN::LayerId, Option<LN::CellId>);

    // Provided method
    fn get_best_pin_access_location(
        &self,
        chip: &LN,
        pin_inst: &LN::PinInstId
    ) -> (Point<LN::Coord>, LN::LayerId) { ... }
}
Query interface for precomputed pin access locations. This is intended to guide the router.

Required Methods

source

fn get_best_pin_access_location_with_via( &self, chip: &LN, pin_inst: &LN::PinInstId ) -> (Point<LN::Coord>, LN::LayerId, Option<LN::CellId>)

Get the absolute coordinates, layer and suggested via cell for the ‘best’ access point of the given pin instance.

Provided Methods

source

fn get_best_pin_access_location( &self, chip: &LN, pin_inst: &LN::PinInstId ) -> (Point<LN::Coord>, LN::LayerId)

Get the absolute coordinates and layer for the ‘best’ access point of the given pin instance.

Implementors