pub struct SimpleRoutingProblem<'a, LN, RoutingGuide = ()>where
    LN: L2NBase,{
    pub chip: &'a LN,
    pub top_cell: LN::CellId,
    pub nets: Vec<LN::NetId>,
    pub net_weights: HashMap<LN::NetId, f64>,
    pub boundary: Option<SimpleRPolygon<LN::Coord>>,
    pub routing_guides: HashMap<LN::NetId, RoutingGuide>,
}
Simple representation of the global and detail routing problems. Implements the RoutingProblem traits.

Fields

chip: &'a LN

A fused layout-netlist structure.

top_cell: LN::CellId

The ID of the top cell to be routed.

nets: Vec<LN::NetId>

The IDs of the nets to be routed.

net_weights: HashMap<LN::NetId, f64>

Weights of nets for optimizing the total wire-length. Default weight is 1.0. A net with weight 0.0 will not be optimized for length while a net with a high weight will be optimized for wiring length much more aggressively.

boundary: Option<SimpleRPolygon<LN::Coord>>

All routes should be contained within this boundary, if it is specified.

routing_guides: HashMap<LN::NetId, RoutingGuide>

Global routes.

Implementations

source

impl<'a, LN: L2NBase, RG> SimpleRoutingProblem<'a, LN, RG>

source

pub fn new(chip: &'a LN, top_cell: LN::CellId) -> Self

Create a new routing problem. By default, no nets are included. Nets which should be routed need to be added to the nets field.

source

pub fn with_routing_guides(self, routing_guides: HashMap<LN::NetId, RG>) -> Self

Set global routes.