pub trait RoutingGuide<C: L2NBase> {
    // Required methods
    fn contains_point(&self, layer: &C::LayerId, p: Point<C::Coord>) -> bool;
    fn to_rectangles(&self) -> Vec<(Rect<C::Coord>, C::LayerId)>;
}
Routing guide for a single net.

Required Methods

source

fn contains_point(&self, layer: &C::LayerId, p: Point<C::Coord>) -> bool

Test if a point on a layer is included in the routing guide.

source

fn to_rectangles(&self) -> Vec<(Rect<C::Coord>, C::LayerId)>

Represent the routing guide as a collection of rectangles.

Implementors