Function libreda_pnr::util::pin_detection::assign_pin_shapes_from_text_labels
source · pub fn assign_pin_shapes_from_text_labels<L: L2NEdit<Coord = Coord>>(
layout: &mut L,
cell: &L::CellId,
pin_shape_layer: &L::LayerId,
label_layer: &L::LayerId
)Expand description
Associate pins and shapes based on a layer containing all polygon shapes and a layer containing text labels. The text labels mark the shapes that belong to a pin. For each text label all this shapes are grouped together.
The naive algorithm used is very inefficient but good enough for standard-cells. Especially if it is used in a pre-computation step which is not time-critical.
Parameters
layout: The layout and netlist data structure.cell: The cell of which pins should be found.pin_shape_layer_id: The layer which contains the pin shapes.label_layer_id: The layer which contains the text labels of the pins.