pub struct CellInstRef<'a, H>where
H: HierarchyBase + ?Sized,{ /* private fields */ }Expand description
Default implementation for CellInstRef.
This is just a wrapper around a netlist and a cell ID.
Implementations
Sourceimpl<'a, H> CellInstRef<'a, H>where
H: HierarchyBase,
impl<'a, H> CellInstRef<'a, H>where
H: HierarchyBase,
Sourcepub fn id(&self) -> <H as HierarchyBase>::CellInstId
pub fn id(&self) -> <H as HierarchyBase>::CellInstId
Get the ID of this cell instance.
Sourcepub fn name(&self) -> Option<<H as HierarchyBase>::NameType>
pub fn name(&self) -> Option<<H as HierarchyBase>::NameType>
Get the name of the cell instance.
Sourcepub fn parent_id(&self) -> <H as HierarchyBase>::CellId
pub fn parent_id(&self) -> <H as HierarchyBase>::CellId
Get the ID of the parent cell of this instance.
Sourcepub fn template_id(&self) -> <H as HierarchyBase>::CellId
pub fn template_id(&self) -> <H as HierarchyBase>::CellId
Get the ID of the template cell of this instance.
Sourceimpl<'a, N> CellInstRef<'a, N>where
N: NetlistBase,
impl<'a, N> CellInstRef<'a, N>where
N: NetlistBase,
Sourcepub fn each_pin_instance_id(
&self,
) -> impl Iterator<Item = <N as NetlistBase>::PinInstId>
pub fn each_pin_instance_id( &self, ) -> impl Iterator<Item = <N as NetlistBase>::PinInstId>
Iterate over the IDs of all pins of this cell.
Sourcepub fn each_pin_instance(&self) -> impl Iterator<Item = PinInstRef<'a, N>>
pub fn each_pin_instance(&self) -> impl Iterator<Item = PinInstRef<'a, N>>
Iterate over all pins of this cell.
Sourceimpl<'a, L> CellInstRef<'a, L>where
L: LayoutBase,
impl<'a, L> CellInstRef<'a, L>where
L: LayoutBase,
Sourcepub fn get_transform(&self) -> SimpleTransform<<L as LayoutBase>::Coord>
pub fn get_transform(&self) -> SimpleTransform<<L as LayoutBase>::Coord>
Get the geometric transform that describes the location of a cell instance relative to its parent.