pub struct PlacementProblemOverlay<'a, C: L2NBase> {
pub placement_problem: &'a dyn PlacementProblem<C>,
pub initial_positions: HashMap<C::CellInstId, SimpleTransform<C::Coord>>,
pub placement_status: HashMap<C::CellInstId, PlacementStatus>,
pub net_weights: HashMap<C::NetId, f64>,
}Expand description
Overlay data for PlacementProblems.
This struct takes a PlacementProblem and stores updates of initial positions, placement status
and net weights. All values which where not set to new values default back to the underlying
PlacementProblem.
This allows to update such values of a immutable PlacementProblem with no cloning.
Fields
placement_problem: &'a dyn PlacementProblem<C>Underlying placement problem.
initial_positions: HashMap<C::CellInstId, SimpleTransform<C::Coord>>Updates for initial positions.
placement_status: HashMap<C::CellInstId, PlacementStatus>Updates for placement status.
net_weights: HashMap<C::NetId, f64>Updates for net weights.
Implementations
sourceimpl<'a, C: L2NBase> PlacementProblemOverlay<'a, C>
impl<'a, C: L2NBase> PlacementProblemOverlay<'a, C>
sourcepub fn new(placement_problem: &'a dyn PlacementProblem<C>) -> Self
pub fn new(placement_problem: &'a dyn PlacementProblem<C>) -> Self
Create a new overlay over placement_problem without any updates.
The returned placement problem will return the same values but they can
be updated without changing the underlying values.