Struct libreda_pnr::route::airwire_router::AirWireRouter
source · pub struct AirWireRouter {
air_wire_layer: u8,
wire_thickness: SInt,
full_mesh: bool,
}Expand description
Router that creates air wires between routing terminals in a star-topology. This does not produce a legal routing and has the only purpose to visualize the connectivity of components.
Fields
air_wire_layer: u8Layer for the air wires.
wire_thickness: SIntWire thickness.
full_mesh: boolDraw a full mesh instead of a star network.
Implementations