pub fn extract_and_plot_net_terminal_geometries<LN>(
chip: &mut LN,
top_cell: &LN::CellId,
destination_cell: Option<&LN::CellId>
) -> HashMap<LN::NetId, Vec<(Polygon<LN::Coord>, LN::LayerId)>>where
LN: L2NEdit,
LN::Coord: PrimInt + NumCast,Expand description
Extract the flattened terminal geometries of all nets in the top_cell.
If the destination_cell is given, the terminals will be written to its layout with additional
text annotations for debugging.